@@ -23,10 +23,10 @@
 
 #include "bitset.h"
 
-extern size_t ebitset_bytes (bitset_bindex);
+size_t ebitset_bytes (bitset_bindex);
 
-extern bitset ebitset_init (bitset, bitset_bindex);
+bitset ebitset_init (bitset, bitset_bindex);
 
-extern void ebitset_release_memory (void);
+void ebitset_release_memory (void);
 
 #endif
