@@ -1,7 +1,7 @@
 /* Lists of symbols for Bison
 
-   Copyright (C) 2002, 2005-2007, 2009-2015 Free Software Foundation,
-   Inc.
+   Copyright (C) 2002, 2005-2007, 2009-2015, 2018 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -192,7 +192,7 @@ symbol_list_n_get (symbol_list *l, int n)
 uniqstr
 symbol_list_n_type_name_get (symbol_list *l, int n)
 {
-  return symbol_list_n_get (l, n)->content.sym->type_name;
+  return symbol_list_n_get (l, n)->content.sym->content->type_name;
 }
 
 bool
@@ -210,8 +210,8 @@ symbol_list_code_props_set (symbol_list *node, code_props_type kind,
     {
     case SYMLIST_SYMBOL:
       symbol_code_props_set (node->content.sym, kind, cprops);
-      if (node->content.sym->status == undeclared)
-        node->content.sym->status = used;
+      if (node->content.sym->content->status == undeclared)
+        node->content.sym->content->status = used;
       break;
     case SYMLIST_TYPE:
       semantic_type_code_props_set
